The module provides a wrapper over the DAWG with separate
Codec for values encoding, which is beneficial when the set
of possible DAWG values is small but individual values occupy
a lot of memory.
NOTE: Useless values are not deleted from the codec when
deleting the DAWG entry.